@@ -99,7 +99,9 @@ def _format(response):
             response['status_detail'] = map_errors[id_error]
         else:
             response['status_detail'] = 'error desconocido'
-
+    elif response['status'] == 'annulled' or response['status'] == 'refunded':
+        response['status'] = 'refunded'
+        response['status_detail'] = 'refunded'
     date = parse_date(response['date']).astimezone(arg_tz)
     result = {
         'id': response['site_transaction_id'],
