@@ -26,7 +26,10 @@ def _format(response):
         'status': response['status'],
         'status_detail': response['status_detail'],
         'card': _format_card(response),
-        'payment_day': parse_date(response['date_created'])     # es igual a date_created
+        'payment_day': parse_date(response['date_created']) ,    # es igual a date_created
+        'statement_descriptor': response['statement_descriptor'],
+        'payment_method_id': response['payment_method_id'],
+        'installments': response['installments']
     }
 
 
